use strict;
use warnings;
use lib "../local/lib/perl5";
use Net::Azure::CognitiveServices::Face;
use JSON 'encode_json';

# 長い名前なので変数に入れて短くする
my $cog = 'Net::Azure::CognitiveServices::Face';

# 環境変数から、Face APIの設定値を持ってくる
$cog->endpoint($ENV{FACEAPI_URL});
$cog->access_key($ENV{FACEAPI_KEY});

# HTTPクエリパラメータimageの参照
my $image_url = $ENV{REQ_QUERY_IMAGE};

# デフォルトのレスポンスを定義しておく
my $res = {
    status  => 400,
    headers => {'Content-Type' => 'application/json'},
    body => {
        message => 'parameter "image" is required',
    }
};

# 画像URLが指定されている場合のみ顔認識を試みる
if ($image_url) {

    # Face APIクライアントを使って顔認識させる。
    my $faceapi = $cog->Face;
    my $result  = $faceapi->detect(
        $image_url, 
        returnFaceAttributes => ['age', 'gender']
    );

    # 認識した顔情報から年齢と性別を抽出する。
    my @faces = ();
    if ($result->[0]) {
        @faces = map { $_->{faceAttributes} } @$result;
    }

    # レスポンスデータを上書きする
    $res = {
        status => 200,
        headers => {
            'Content-Type' => 'application/json'
        },
        body => {
            faces => [@faces]
        }
    };
}

# レスポンスを返す
print encode_json($res);
