### Azureリソース セットアップスクリプト
### 2018-12-21 ytnobody
###
### * Perl Hackers Hub vol.109 で作成した顔認識システムを
###   Microsoft Azure上に全自動でデプロイするスクリプトです。
### 
### * Azure CLI v2 と cpanm が必要です。
###

## --- ここから設定項目（変えなくても動きます） --- ##

# リソースグループ名
AZ_RG_NAME=facedetect-`date +%s`

# リージョン
AZ_RG_REGION=japaneast

# ストレージアカウント名
AZ_STORAGE_NAME=facedetect`date +%s`

# Functionsリソース名
AZ_FUNC_NAME=$AZ_RG_NAME

# Cognitive Service アカウント名
AZ_CS_NAME=$AZ_RG_NAME

## --- ここまで設定項目 この先は変えなくてOKです --- ##

### CPANモジュールを導入
cpanm -n -L local --installdeps .

### リソースグループの作成 
az group create \
  --name $AZ_RG_NAME \
  --location $AZ_RG_REGION

### ストレージアカウントの作成
az storage account create \
  --resource-group $AZ_RG_NAME \
  --name $AZ_STORAGE_NAME \
  --sku Standard_LRS

### Functionsリソースの作成
az functionapp create \
  --resource-group $AZ_RG_NAME \
  --name $AZ_FUNC_NAME \
  --storage-account $AZ_STORAGE_NAME \
  --consumption-plan-location $AZ_RG_REGION

### ランタイムバージョンの変更
az functionapp config appsettings set \
  --resource-group $AZ_RG_NAME \
  --name $AZ_FUNC_NAME \
  --settings FUNCTIONS_EXTENSION_VERSION=~1

### Face APIの設定
az cognitiveservices account create \
  --resource-group $AZ_RG_NAME \
  --name $AZ_CS_NAME \
  --sku F0 \
  --kind Face \
  --location $AZ_RG_REGION \
  --yes

### Face APIエンドポイントをメモ
FACEAPI_URL=`az cognitiveservices account show \
  --resource-group $AZ_RG_NAME \
  --name $AZ_CS_NAME | 
  grep endpoint |
  sed s'/^ *"endpoint": "//; s/",//;'`

### Face APIアクセスキーをメモ
FACEAPI_KEY=`az cognitiveservices account keys list \
  --resource-group $AZ_RG_NAME \
  --name $AZ_CS_NAME |
  grep key1 |
  sed s'/^ *"key1": "//; s/",//;'`

### Face APIの各設定をFunctionsリソースの環境変数に設定する
az functionapp config appsettings set \
  --resource-group $AZ_RG_NAME \
  --name $AZ_FUNC_NAME \
  --settings \
    FACEAPI_URL=$FACEAPI_URL \
    FACEAPI_KEY=$FACEAPI_KEY

### デプロイ
zip -r FaceDetectProject.zip ./ &&
az functionapp deployment source config-zip \
  --resource-group $AZ_RG_NAME \
  --name $AZ_FUNC_NAME \
  --src FaceDetectProject.zip